@@ -21,7 +21,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA or visit the web at
  * http://www.gnu.org.
  * 
- * $Id: GeometryCollection.java 9324 2012-02-27 22:08:12Z pramsey $
+ * $Id: GeometryCollection.java 12202 2014-01-30 19:17:00Z pramsey $
  */
 
 package org.postgis;
@@ -34,7 +34,7 @@ import java.sql.SQLException;
  * 
  * @author markus.schaber@logix-tt.com
  * 
- * $Id: GeometryCollection.java 9324 2012-02-27 22:08:12Z pramsey $
+ * $Id: GeometryCollection.java 12202 2014-01-30 19:17:00Z pramsey $
  */
 
 public class GeometryCollection extends ComposedGeom {
@@ -68,10 +68,10 @@ public class GeometryCollection extends ComposedGeom {
     }
 
     protected void innerWKT(StringBuffer SB) {
-        subgeoms[0].outerWKT(SB, false);
+        subgeoms[0].outerWKT(SB, true);
         for (int i = 1; i < subgeoms.length; i++) {
             SB.append(',');
-            subgeoms[i].outerWKT(SB, false);
+            subgeoms[i].outerWKT(SB, true);
         }
     }
 
