@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: lwgeom_functions_basic.c 12090 2013-11-05 19:57:22Z pramsey $
+ * $Id: lwgeom_functions_basic.c 12671 2014-06-26 22:43:51Z pramsey $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * http://postgis.refractions.net
@@ -1878,6 +1878,13 @@ Datum LWGEOM_segmentize2d(PG_FUNCTION_ARGS)
 	}
 
 	inlwgeom = lwgeom_from_gserialized(ingeom);
+	
+	if ( lwgeom_is_empty(inlwgeom) )
+	{
+		lwgeom_free(inlwgeom);
+		PG_RETURN_POINTER(ingeom);
+	}
+	
 	outlwgeom = lwgeom_segmentize2d(inlwgeom, dist);
 
 	/* Copy input bounding box if any */
