@@ -17,6 +17,7 @@
 #include "fmgr.h"
 #include "miscadmin.h"
 #include "utils/array.h"
+
 #include "utils/builtins.h"
 #include "utils/hsearch.h"
 #include "utils/memutils.h"
@@ -24,6 +25,13 @@
 #include "funcapi.h"
 
 #include "../postgis_config.h"
+
+#if POSTGIS_PGSQL_VERSION >= 93
+#include "access/htup_details.h"
+#else
+#include "access/htup.h"
+#endif
+
 #include "lwgeom_functions_analytic.h" /* for point_in_polygon */
 #include "lwgeom_geos.h"
 #include "liblwgeom_internal.h"
@@ -1824,7 +1832,7 @@ Datum isvaliddetail(PG_FUNCTION_ARGS)
 	GEOSGeometry *geos_location = NULL;
 	LWGEOM *location = NULL;
 	char valid = 0;
-	Datum result;
+	HeapTupleHeader result;
 	TupleDesc tupdesc;
 	HeapTuple tuple;
 	AttInMetadata *attinmeta;
@@ -1896,7 +1904,9 @@ Datum isvaliddetail(PG_FUNCTION_ARGS)
 	values[2] =  location ? lwgeom_to_hexwkb(location, WKB_EXTENDED, 0) : 0;
 
 	tuple = BuildTupleFromCStrings(attinmeta, values);
-	result = HeapTupleGetDatum(tuple);
+	result = (HeapTupleHeader) palloc(tuple->t_len);
+	memcpy(result, tuple->t_data, tuple->t_len);
+	heap_freetuple(tuple);
 
 	PG_RETURN_HEAPTUPLEHEADER(result);
 
@@ -1989,7 +1999,7 @@ Datum contains(PG_FUNCTION_ARGS)
 	LWGEOM *lwgeom;
 	LWPOINT *point;
 	RTREE_POLY_CACHE *poly_cache;
-	bool result;
+	int result;
 	PrepGeomCache *prep_cache;
 
 	geom1 = (GSERIALIZED *)  PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
@@ -2212,7 +2222,7 @@ Datum covers(PG_FUNCTION_ARGS)
 {
 	GSERIALIZED *geom1;
 	GSERIALIZED *geom2;
-	bool result;
+	int result;
 	GBOX box1, box2;
 	int type1, type2;
 	LWGEOM *lwgeom;
@@ -2367,7 +2377,7 @@ Datum coveredby(PG_FUNCTION_ARGS)
 	GSERIALIZED *geom1;
 	GSERIALIZED *geom2;
 	GEOSGeometry *g1, *g2;
-	bool result;
+	int result;
 	GBOX box1, box2;
 	LWGEOM *lwgeom;
 	LWPOINT *point;
@@ -2493,7 +2503,7 @@ Datum crosses(PG_FUNCTION_ARGS)
 	GSERIALIZED *geom1;
 	GSERIALIZED *geom2;
 	GEOSGeometry *g1, *g2;
-	bool result;
+	int result;
 	GBOX box1, box2;
 
 	geom1 = (GSERIALIZED *)PG_DETOAST_DATUM(PG_GETARG_DATUM(0));
@@ -2561,7 +2571,7 @@ Datum geos_intersects(PG_FUNCTION_ARGS)
 	GSERIALIZED *geom1;
 	GSERIALIZED *geom2;
 	GSERIALIZED *serialized_poly;
-	bool result;
+	int result;
 	GBOX box1, box2;
 	int type1, type2, polytype;
 	LWPOINT *point;
