@@ -1,5 +1,5 @@
 /*
- * $Id: raster2pgsql.c 12093 2013-11-06 05:12:11Z dustymugs $
+ * $Id: raster2pgsql.c 12748 2014-07-07 08:57:57Z strk $
  *
  * PostGIS raster loader
  * http://trac.osgeo.org/postgis/wiki/WKTRaster
@@ -1075,9 +1075,7 @@ create_index(
 		rtdealloc(_column);
 		return 0;
 	}
-	sprintf(sql, "CREATE INDEX \"%s_%s_gist\" ON %s%s USING gist (st_convexhull(%s))%s%s;",
-		_table,
-		_column,
+	sprintf(sql, "CREATE INDEX ON %s%s USING gist (st_convexhull(%s))%s%s;",
 		(schema != NULL ? schema : ""),
 		table,
 		column,
