@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-
+#$| = 1;
 use File::Basename;
 use File::Temp 'tempdir';
 #use File::Which;
@@ -20,17 +20,11 @@ use strict;
 #  Check output against <testname>_expected
 ##################################################################
 
-if ( @ARGV < 1 )
-{
-	usage();
-}
-
-
 ##################################################################
 # Global configuration items
 ##################################################################
 
-our $DB = "postgis_reg";
+our $DB = $ENV{"POSTGIS_REGRESS_DB"} || "postgis_reg";
 our $REGDIR = abs_path(dirname($0));
 our $SHP2PGSQL = $REGDIR . "/../loader/shp2pgsql";
 our $PGSQL2SHP = $REGDIR . "/../loader/pgsql2shp";
@@ -50,6 +44,10 @@ my $OPT_WITH_RASTER = 0;
 my $OPT_WITH_SFCGAL = 0;
 my $OPT_EXPECT = 0;
 my $OPT_EXTENSIONS = 0;
+my $OPT_EXTVERSION = '';
+my $OPT_UPGRADE_PATH = '';
+my $OPT_UPGRADE_FROM = '';
+my $OPT_UPGRADE_TO = '';
 my $VERBOSE = 0;
 
 GetOptions (
@@ -57,6 +55,7 @@ GetOptions (
 	'clean' => \$OPT_CLEAN,
 	'nodrop' => \$OPT_NODROP, 
 	'upgrade' => \$OPT_UPGRADE,
+	'upgrade-path=s' => \$OPT_UPGRADE_PATH,
 	'nocreate' => \$OPT_NOCREATE,
 	'topology' => \$OPT_WITH_TOPO,
 	'raster' => \$OPT_WITH_RASTER,
@@ -65,6 +64,28 @@ GetOptions (
 	'extensions' => \$OPT_EXTENSIONS
 	);
 
+if ( @ARGV < 1 )
+{
+	usage();
+}
+
+if ( $OPT_UPGRADE_PATH )
+{
+  if ( ! $OPT_EXTENSIONS )
+  {
+    die "--upgrade-path is only supported with --extensions"
+  }
+  $OPT_UPGRADE = 1; # implied 
+  my @path = split ('--', $OPT_UPGRADE_PATH);
+  $OPT_UPGRADE_FROM = $path[0]
+    || die "Malformed upgrade path, <from>:<to> expected, $OPT_UPGRADE_PATH given";
+  $OPT_UPGRADE_TO = $path[1]
+    || die "Malformed upgrade path, <from>:<to> expected, $OPT_UPGRADE_PATH given";
+  print "Upgrade path: ${OPT_UPGRADE_FROM} --> ${OPT_UPGRADE_TO}\n";
+}
+
+
+
 ##################################################################
 # Set the locale to "C" so error messages match
 # Save original locale to set back
@@ -170,7 +191,7 @@ print "TMPDIR is $TMPDIR\n";
 # Prepare the database
 ##################################################################
 
-my @dblist = grep(/$DB/, split(/\n/, `psql -l`));
+my @dblist = grep(/$DB/, split(/\n/, `psql -Xl`));
 my $dbcount = @dblist;
 
 if ( $dbcount == 0 )
@@ -221,6 +242,9 @@ if ( $OPT_UPGRADE )
 	{
 	  upgrade_spatial();
   }
+
+  # Update libver
+  $libver = sql("select postgis_lib_version()");
 }
 
 
@@ -235,9 +259,14 @@ my $libbuilddate = sql("select postgis_lib_build_date()");
 my $pgsqlver = sql("select version()");
 my $gdalver = sql("select postgis_gdal_version()") if $OPT_WITH_RASTER;
 my $sfcgalver = sql("select postgis_sfcgal_version()") if $OPT_WITH_SFCGAL;
+my $scriptver = sql("select postgis_scripts_installed()");
+my $raster_scriptver = sql("select postgis_raster_scripts_installed()")
+  if ( $OPT_WITH_RASTER );
 
 print "$pgsqlver\n";
 print "  Postgis $libver - r${svnrev} - $libbuilddate\n";
+print "  scripts ${scriptver}\n";
+print "  raster scripts ${raster_scriptver}\n" if ( $OPT_WITH_RASTER );
 print "  GEOS: $geosver\n" if $geosver;
 print "  PROJ: $projver\n" if $projver;
 print "  SFCGAL: $sfcgalver\n" if $sfcgalver;
@@ -294,9 +323,13 @@ foreach $TEST (@ARGV)
 		my $rv = run_simple_test("${TEST}.sql", "${TEST}_expected");
 		pass() if $rv;
 	}
+	elsif ( -r "${TEST}.dmp" )
+	{
+		pass() if run_dumper_test();
+	}
 	else
 	{
-		print " skipped (can't read ${TEST}.sql)\n";
+		print " skipped (can't read any ${TEST}.{sql,dbf,tif,dmp})\n";
 		$SKIP++;
 		next;
 	}
@@ -367,17 +400,19 @@ exit($FAIL);
 sub usage 
 {
 	die qq{
-Usage: $0 <testname> [<testname>]
+Usage: $0 [<options>] <testname> [<testname>]
 Options:
-  --verbose    be verbose about failures
-  --nocreate   do not create the regression database on start
-  --upgrade    source the upgrade scripts on start
-  --nodrop     do not drop the regression database on exit
-  --raster     load also raster extension
-  --topology   load also topology extension
-  --sfcgal     use also sfcgal backend
-  --clean      cleanup test logs on exit
-  --expect     save obtained output as expected
+  -v, --verbose   be verbose about failures
+  --nocreate      do not create the regression database on start
+  --upgrade       source the upgrade scripts on start
+  --nodrop        do not drop the regression database on exit
+  --raster        load also raster extension
+  --topology      load also topology extension
+  --sfcgal        use also sfcgal backend
+  --clean         cleanup test logs on exit
+  --expect        save obtained output as expected
+  --extension     load using extensions
+  --upgrade-path  upgrade path, format <from>--<to>
 };
 
 }
@@ -458,8 +493,8 @@ sub run_simple_sql
 	# Dump output to a temp file.
 	my $tmpfile = sprintf("%s/test_%s_tmp", $TMPDIR, $RUN);
 	my $cmd = "psql -v \"VERBOSITY=terse\" -tXA $DB < $sql > $tmpfile 2>&1";
+	#print($cmd);
 	my $rv = system($cmd);
-
 	# Check if psql errored out.
 	if ( $rv != 0 ) 
 	{
@@ -470,6 +505,7 @@ sub run_simple_sql
 	# Check for ERROR lines
 	open FILE, "$tmpfile";
 	my @lines = <FILE>;
+	close FILE;
 	my @errors = grep(/^ERROR/, @lines);
 	
 	if ( @errors > 0 )
@@ -572,7 +608,7 @@ sub run_simple_test
 
 	# Strip the lines we don't care about
 	@lines = grep(!/^\$/, @lines);
-	@lines = grep(!/^(INSERT|DELETE|UPDATE|SELECT)/, @lines);
+	@lines = grep(!/^(INSERT|DELETE|UPDATE|SELECT|COPY)/, @lines);
 	@lines = grep(!/^(CONTEXT|RESET|ANALYZE)/, @lines);
 	@lines = grep(!/^(DROP|CREATE|VACUUM)/, @lines);
 	@lines = grep(!/^(LOG|SET|TRUNCATE)/, @lines);
@@ -603,7 +639,7 @@ sub run_simple_test
 	
 	if ( $OPT_EXPECT )
 	{
-		print " expected\n";
+		print " (expected)";
 		copy($outfile, $expected);
 	}
 	else
@@ -713,7 +749,7 @@ sub run_loader_and_check_output
 # $1 - Description of this run of the dumper, used for error messages.
 # $2 - Table name to dump from.
 # $3 - "Expected" .shp file to compare with.
-# $3 - If you pass true, this will run the loader even if neither
+# $4 - If you pass true, this will run the loader even if neither
 #      of the expected results files exists (though of course
 #      the results won't be compared with anything).
 ##################################################################
@@ -732,6 +768,7 @@ sub run_dumper_and_check_output
 		show_progress();
 		$cmd = "${PGSQL2SHP} -f ${TMPDIR}/dumper $DB $tblname > $errfile 2>&1";
 		$rv = system($cmd);
+	
 		if ( $rv )
 		{
 			fail("$description: dumping loaded table", $errfile);
@@ -739,9 +776,11 @@ sub run_dumper_and_check_output
 		}
 
 		# Compare with expected output if there is any.
+		
 		if ( -r $expected_shp_file )
 		{
 			show_progress();
+			
 			my $diff = diff($expected_shp_file,  "$TMPDIR/dumper.shp");
 			if ( $diff )
 			{
@@ -922,6 +961,89 @@ sub run_loader_test
 	return 1;
 }
 
+##################################################################
+#  run_dumper_test 
+#
+#  Run dumper and compare output with various expectances
+#  test and run simple test with provided expected output. 
+#
+# input is ${TEST}.dmp, where last line is considered to be the
+# [table|query] argument for pgsql2shp and all the previous lines,
+# if any are 
+#
+##################################################################
+sub run_dumper_test 
+{
+  my $dump_file  = "${TEST}.dmp";
+
+  # ON_ERROR_STOP is used by psql to return non-0 on an error
+  my $psql_opts="--no-psqlrc --variable ON_ERROR_STOP=true";
+
+  my $shpfile = "${TMPDIR}/dumper-" . basename(${TEST}) . "-shp";
+  my $outfile = "${TMPDIR}/dumper-" . basename(${TEST}) . ".out";
+  my $errfile = "${TMPDIR}/dumper-" . basename(${TEST}) . ".err";
+
+  # Produce the output SHP file.
+  open DUMPFILE, "$dump_file" or die "Cannot open dump file $dump_file\n";
+  sleep(1);
+  my @dumplines = <DUMPFILE>;
+  close DUMPFILE;
+  my $dumpstring = join '', @dumplines;
+  chop($dumpstring);
+  my @cmd = ("${PGSQL2SHP}", "-f", ${shpfile}, ${DB}, ${dumpstring});
+  open my $stdout_save, '>&', *STDOUT or die "Cannot dup stdout\n";
+  open my $stderr_save, '>&', *STDERR or die "Cannot dup stdout\n";
+  open STDOUT, ">${outfile}" or die "Cannot write to ${outfile}\n";
+  open STDERR, ">${errfile}" or die "Cannot write to ${errfile}\n";
+  my $rv = system(@cmd);
+  open STDERR, '>&', $stderr_save;
+  open STDOUT, '>&', $stdout_save;
+  #sleep(3);
+  show_progress();
+
+  if ( $rv )
+  {
+    fail("dumping", "$errfile");
+    return 0;
+  }
+
+  my $numtests = 0;
+  foreach my $ext ("shp","prj","dbf","shx") {
+    my $obtained = ${shpfile}.".".$ext;
+    my $expected = ${TEST}."_expected.".$ext;
+    if ( $OPT_EXPECT )
+    {
+      copy($obtained, $expected);
+    }
+    elsif ( -r ${expected} ) {
+      show_progress();
+      $numtests++;
+      my $diff = diff($expected,  $obtained);
+      if ( $diff )
+      {
+        my $diffile = sprintf("%s/dumper_test_%s_diff", $TMPDIR, $ext);
+        open(FILE, ">$diffile");
+        print FILE $diff;
+        close(FILE);
+        fail("diff expected obtained", $diffile);
+        return 0;
+      }
+    }
+  }
+
+  #show_progress();
+
+  if ( $OPT_EXPECT ) {
+    print " (expected)";
+  }
+  elsif ( ! $numtests ) {
+    fail("no expectances!");
+    return 0;
+  }
+
+	return 1;
+}
+
 
 ##################################################################
 #  run_raster_loader_test 
@@ -1030,24 +1152,37 @@ sub load_sql_file
 # Prepare the database for spatial operations (extension method)
 sub prepare_spatial_extensions
 {
-	print "Preparing db '${DB}' using 'CREATE EXTENSION'\n"; 
-
 	# ON_ERROR_STOP is used by psql to return non-0 on an error
 	my $psql_opts = "--no-psqlrc --variable ON_ERROR_STOP=true";
-    my $cmd = "psql $psql_opts -c \"CREATE EXTENSION postgis\" $DB >> $REGRESS_LOG 2>&1";
-    my $rv = system($cmd);
+	my $sql = "CREATE EXTENSION postgis";
+	if ( $OPT_UPGRADE_FROM ) {
+		$sql .= " VERSION '" . $OPT_UPGRADE_FROM . "'";
+	}
 
-	die "\nError encountered creating EXTENSION POSTGIS, see $REGRESS_LOG for details\n\n"
-	    if $rv;
+	print "Preparing db '${DB}' using: ${sql}\n"; 
 
-    if ( $OPT_WITH_TOPO )
-    {
-        $cmd = "psql $psql_opts -c \"CREATE EXTENSION postgis_topology\" $DB >> $REGRESS_LOG 2>&1";
-        $rv = system($cmd);
-    	die "\nError encountered creating EXTENSION POSTGIS_TOPOLOGY, see $REGRESS_LOG for details\n\n"
-    	    if $rv;
-    }
-    return 1;
+	my $cmd = "psql $psql_opts -c \"". $sql . "\" $DB >> $REGRESS_LOG 2>&1";
+	my $rv = system($cmd);
+
+  if ( $rv ) {
+  	fail "Error encountered creating EXTENSION POSTGIS", $REGRESS_LOG;
+  	die;
+	}
+
+	if ( $OPT_WITH_TOPO )
+	{
+		my $sql = "CREATE EXTENSION postgis_topology";
+		if ( $OPT_UPGRADE_FROM ) {
+			$sql .= " VERSION '" . $OPT_UPGRADE_FROM . "'";
+		}
+ 		$cmd = "psql $psql_opts -c \"" . $sql . "\" $DB >> $REGRESS_LOG 2>&1";
+		$rv = system($cmd);
+  	if ( $rv ) {
+  		fail "Error encountered creating EXTENSION POSTGIS_TOPOLOGY", $REGRESS_LOG;
+  		die;
+		}
+ 	}
+ 	return 1;
 }
 
 # Prepare the database for spatial operations (old method)
@@ -1136,21 +1271,30 @@ sub upgrade_spatial
 # Upgrade an existing database (soft upgrade, extension method)
 sub upgrade_spatial_extensions
 {
-    print "Upgrading PostGIS in '${DB}' using 'ALTER EXTENSION'\n" ;
-
     # ON_ERROR_STOP is used by psql to return non-0 on an error
     my $psql_opts = "--no-psqlrc --variable ON_ERROR_STOP=true";
-    my $cmd = "psql $psql_opts -c \"ALTER EXTENSION postgis UPDATE TO '${libver}next'\" $DB >> $REGRESS_LOG 2>&1";
+    my $nextver = $OPT_UPGRADE_TO ? "${OPT_UPGRADE_TO}" : "${libver}next";
+    my $sql = "ALTER EXTENSION postgis UPDATE TO '${nextver}'";
+
+    print "Upgrading PostGIS in '${DB}' using: ${sql}\n" ;
+
+    my $cmd = "psql $psql_opts -c \"" . $sql . "\" $DB >> $REGRESS_LOG 2>&1";
+    #print "CMD: " . $cmd . "\n";
     my $rv = system($cmd);
-    die "\nError encountered altering EXTENSION POSTGIS, see $REGRESS_LOG for details\n\n"
-	    if $rv;
+    if ( $rv ) {
+      fail "Error encountered altering EXTENSION POSTGIS", $REGRESS_LOG;
+      die;
+    }
 
     if ( $OPT_WITH_TOPO ) 
     {
-      my $cmd = "psql $psql_opts -c \"ALTER EXTENSION postgis_topology UPDATE TO '${libver}next'\" $DB >> $REGRESS_LOG 2>&1";
+      my $sql = "ALTER EXTENSION postgis_topology UPDATE TO '${nextver}'";
+      my $cmd = "psql $psql_opts -c \"" . $sql . "\" $DB >> $REGRESS_LOG 2>&1";
       my $rv = system($cmd);
-      die "\nError encountered altering EXTENSION POSTGIS_TOPOLOGY, see $REGRESS_LOG for details\n\n"
-        if $rv;
+      if ( $rv ) {
+        fail "Error encountered altering EXTENSION POSTGIS_TOPOLOGY", $REGRESS_LOG;
+        die;
+      }
     }
     
     return 1;
@@ -1226,7 +1370,7 @@ sub uninstall_spatial
 		}
 		else
 		{
-            pass("($OBJ_COUNT_PRE)");
+			pass("($OBJ_COUNT_PRE)");
 			return 1;
 		}
 	}
@@ -1240,12 +1384,12 @@ sub diff
 	my $diffstr = '';
 
 	if ( $sysdiff ) {
-		$diffstr = `diff --strip-trailing-cr -u $expected_file $obtained_file`;
+		$diffstr = `diff --strip-trailing-cr -u $expected_file $obtained_file 2>&1`;
 		return $diffstr;
 	}
 
-	open(OBT, $obtained_file) || die "Cannot open $obtained_file\n";
-	open(EXP, $expected_file) || die "Cannot open $expected_file\n";
+	open(OBT, $obtained_file) || return "Cannot open $obtained_file\n";
+	open(EXP, $expected_file) || return "Cannot open $expected_file\n";
 	my $lineno = 0;
 	while (!eof(OBT) or !eof(EXP)) {
 		# TODO: check for premature end of one or the other ?
